from setuptools import setup, find_packages


def get_install_requires():
    install_requires = []

    with open("requirements.txt", "r") as req_txt:
        install_requires = map(lambda s: s.strip(), req_txt.readlines()[2:])

    return list(install_requires)


setup(
    name="lfg-llama",
    version="1.0.100",
    description="LFG, It Really Whips the Llama's Ass 🦙🦙🦙🦙",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    author="Bjarne Oeverli",
    author_email="bjarneocodes@gmail.com",
    packages=find_packages(),
    install_requires=["groq"],
    entry_points={"console_scripts": ["lfg=lfg.cli:main"]},
)



#!/usr/bin/python3

import os
import sys
import argparse
import json
from groq import Groq


client = Groq(api_key=os.environ.get("GROQ_API_KEY"))


def chat(ask):
    system_prompt = "From now on you should act as a system administrator / hacker that is really good at the terminal in linux and mac. All answers should be commands, and nothing else than commands and max 3 commands based on what the user asks for. All should be shown as a command using a bash markdown code block. Commands prefixed with. First the header before code block should be prefixed with # and added before the code block. Then the code block. Then add a short explanation after the code block."

    stream = client.chat.completions.create(
        messages=[
            {"role": "system", "content": system_prompt},
            {"role": "user", "content": ask},
        ],
        model="llama3-8b-8192",
        stream=True,
    )

    for chunk in stream:
        if chunk.choices[0].delta.content != None:
            print(chunk.choices[0].delta.content, end="", flush=True)


def main(arg=None):
    parser = argparse.ArgumentParser(
        description="Use LFG to chat with the Llama as a sysadmin / haxor. \nExample: lfg 'how to kill a process in linux?'"
    )

    if arg:
        chat(" ".join(arg))


sys.exit(main(sys.argv[1:]))
